pywurfl.algorithms.wurfl.handlers.BlackberryMatcher

Package pywurfl :: Package algorithms :: Package wurfl :: Module handlers :: Class BlackberryMatcher |
[hide private]
[frames] | no frames]

# Class BlackberryMatcher

source code

         object --+
                  |
    AbstractMatcher --+
                      |
                     BlackberryMatcher

Instance Methods | [hide private]
can_handle(self, user_agent) | source code
recovery_match(self, user_agent) | source code
get_version(self, user_agent) | source code
Inherited from `AbstractMatcher`: `__call__`, `__init__`, `add`, `catch_all_recovery_match`, `conclusive_match`, `look_for_matching_user_agent` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Variables | [hide private]
| blackberries = ``{``'``2.``'``:` `u'``blackberry_generic_ver2``'``,` `'``3.2``'``:` `u'``bla``...``
Inherited from `AbstractMatcher`: `recovery_map`, `user_agent_map`

Properties | [hide private]
Inherited from `AbstractMatcher`: `user_agents` Inherited from `object`: `__class__`

Method Details | [hide private]

### can_handle(self, user_agent) | source code
Overrides: AbstractMatcher.can_handle

### recovery_match(self, user_agent) | source code
Overrides: AbstractMatcher.recovery_match

Class Variable Details | [hide private]

  ### blackberries Value:
      {'2.': u'blackberry_generic_ver2',
       '3.2': u'blackberry_generic_ver3_sub2',
       '3.3': u'blackberry_generic_ver3_sub30',
       '3.5': u'blackberry_generic_ver3_sub50',
       '3.6': u'blackberry_generic_ver3_sub60',
       '3.7': u'blackberry_generic_ver3_sub70',
       '4.': u'blackberry_generic_ver4'}